Code library for communication between Sapiens Transformers and Sapiens Machine.

# Sapiens Accelerator

This set of algorithms was developed by Sapiens Technology®️ and aims to accelerate the processing of language models through optimizations mediated by the Sapiens Machine library. The two packages work together to accelerate hardware and optimize software, making training and inference possible on modest computing systems and improving performance on high-end hardware.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Sapiens Machine.

```bash
pip install sapiens-accelerator
```

If you have a problem with one or more dependencies, you can install them manually via the requirements file.

```bash
pip install -r requirements.txt
```

## Contributing

We do not accept contributions that may result in changing the original code.

Make sure you are using the appropriate version.

## License

This is proprietary software and its alteration and/or distribution without the developer's authorization is not permitted.
